==> mars-1.1.1.tar.gz: mars-1.1.1/tests/TFP/TFP_36_009/mpu2.c <==
/*
 * Copyright 2008 Sony Corporation
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#include <mars/task.h>
#include <mars_task_test.h>

int mars_task_main(const struct mars_task_args *task_args)
{
	int ret;
	uint64_t mpu_to_mpu_ea = task_args->type.u64[0];
	uint32_t flags = (uint32_t)task_args->type.u64[1];
	uint32_t chk_bit;

	/* wait condition OR */
	while (1) {
		ret = mars_task_event_flag_try_wait(
			mpu_to_mpu_ea,
			flags,
			MARS_TASK_EVENT_FLAG_MASK_OR, NULL);
		if (ret == MARS_SUCCESS)
			break;
		else if (ret == MARS_ERROR_BUSY)
			continue;
		else
			MARS_TEST_ASSERT_ERROR(ret, 0);
	}

	/* check if all bits are cleard */
	chk_bit = 0x01;
	while (flags) {
		if (flags & 0x01) {
			ret = mars_task_event_flag_try_wait(
				mpu_to_mpu_ea,
				chk_bit,
				MARS_TASK_EVENT_FLAG_MASK_OR, NULL);
			/* if bit == 0, try_wait returns BUSY */
			MARS_TEST_ASSERT_ERROR(ret, MARS_ERROR_BUSY);
		}
		flags >>= 1;
		chk_bit <<= 1;
	}
	return 0;
}

==> mars-1.1.5.tar.gz: mars-1.1.5/tests/TFP/TFP_49_002/mpu2.c <==
/*
 * Copyright 2008 Sony Corporation
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#include <string.h>
#include <mars/task.h>
#include "mars_task_test.h"
#include "host_and_mpu.h"

static uint64_t queue_item[2] __attribute__((aligned(16)));

int mars_task_main(const struct mars_task_args *task_args)
{
	uint64_t queue_ea = task_args->type.u64[0];
	uint64_t notify_ea = task_args->type.u64[1];
	int i, ret;

	mars_test_counter_wait(notify_ea, 1);

	for (i = 0; i < QUEUE_DEPTH; i++) {
		ret = mars_task_queue_pop(queue_ea, queue_item);
		MARS_TEST_ASSERT_ERROR(ret, MARS_SUCCESS);

		MARS_TEST_ASSERT(queue_item[0] == i && queue_item[1] == i);
	}

	mars_task_exit(0);

	return 0;
}
